/***********************************************************************/
/*                                                                     */
/*                              Pio (C++)                              */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Estelle Marchand <Estelle.Marchand@inria.fr>                       */
/*                                                                     */
/***********************************************************************/

/* $Id: vector_type.hpp,v 1.9 2014/01/10 19:22:09 fclement Exp $ */

#include "elem.hpp"
#include "single_types.hpp"

#ifndef VECTOR_TYPE_H
#define VECTOR_TYPE_H 

namespace io{
  
  class Vector_type{
    Single_type vector_type;
    //champs du type somme:
    Elem< vector<int> > i;
    Elem< vector<boolean> > b;
    Elem< vector<double> > d;
    Elem< vector<string> > s;
    Elem< vector<float_triple> > ft;
    Elem< vector<float_couple> > fc;
    Elem< vector<int_triple> > it;
    Elem< vector<int_couple> > ic;
    Elem< vector<boolean_triple> > bt;
    Elem< vector<boolean_couple> > bc;
  public:
    Single_type type() const;
    //constructeurs:
    Vector_type(){vector_type=EMPTY;}
    Vector_type(const vector<int> &i);
    Vector_type(const vector<boolean> &b);
    Vector_type(const vector<double> &d);
    Vector_type(const vector<string> &s);
    Vector_type(const vector<float_triple> &ft);
    Vector_type(const vector<float_couple> &fc);
    Vector_type(const vector<int_triple> &it);
    Vector_type(const vector<int_couple> &ic);
    Vector_type(const vector<boolean_triple> &bt);
    Vector_type(const vector<boolean_couple> &bc);
    //conversions:
    vector<int> & to_int();
    vector<boolean> & to_boolean();
    vector<double> & to_float();
    vector<string> & to_string();
    vector<float_triple> & to_float_triple();
    vector<float_couple> & to_float_couple();
    vector<int_triple> & to_int_triple();
    vector<int_couple> & to_int_couple();
    vector<boolean_triple> & to_boolean_triple();
    vector<boolean_couple> & to_boolean_couple();
    const vector<int> & to_int() const ;
    const vector<boolean> & to_boolean() const ;
    const vector<double> & to_float() const ;
    const vector<string> & to_string() const ;
    const vector<float_triple> & to_float_triple() const ;
    const vector<float_couple> & to_float_couple() const ;
    const vector<int_triple> & to_int_triple() const ;
    const vector<int_couple> & to_int_couple() const ;
    const vector<boolean_triple> & to_boolean_triple() const ;
    const vector<boolean_couple> & to_boolean_couple() const ;
    virtual ~Vector_type();
  };
  
}

#endif
