(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2013-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: umatrix_graph.mli,v 1.10 2014-01-28 16:10:02 fclement Exp $ *)

(** {3 Matrix graphs of function} *)

type index = Umatrix_nonempty_set.index
and uindex = Umatrix_nonempty_set.uindex
;;

type domain = Umatrix_nonempty_set.t;;

type sub_domain = Umatrix_nonempty_set.nonempty_subset;;

type 'a images =
  | Constant of 'a
  | Images of 'a array
;;

type 'a t = private
  {
   domain : domain;
   images : 'a images;
  }
;;

val same : 'a t -> 'a t -> bool;;
(** Physical equality of matrix graphs. *)

val same_domain : 'a t -> 'a t -> bool;;
(** Physical equality of domain of matrix graphs. *)

val equal_domain : 'a t -> 'a t -> bool;;
(** Structural equality of domain of matrix graphs. *)

val unique_domain : 'a t -> 'a t -> 'a t;;
(** [unique_domain mg1 mg2] checks that [mg1] and [mg2] have equal domains,
 and returns [mg2] with the same domain as [mg1]. *)

(** {6 Construction functions} *)

val make : 'a Umatrix.t -> 'a t;;

val constant : domain -> 'a -> 'a t;;
val from_array : domain -> 'a array -> 'a t;;
val from_fun : domain -> (index -> uindex -> 'a) -> 'a t;;

(** {6 Access functions} *)

val get_constant : 'a t -> 'a;;
val change_constant : 'a t -> 'a -> 'a t;;

val image : 'a t -> index -> 'a;;
val to_array : 'a t -> 'a array;;

val restriction : 'a t -> sub_domain -> 'a t;;

(** {6 Iterators} *)

val map_images : ('a -> 'b) -> 'a t -> 'b t;;
